
# Type: boolean


A binary (true or false) value

URI: [https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Boolean](https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Boolean)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **Bool** |
